@@ -14,6 +14,10 @@ from poprogress import simple_progress
 
 
 def query4excel(query_content, query_path, output_path, output_name):
+
+    if not output_name.endswith('xlsx') or not output_name.endswith('xls'):
+        print('output_name必须以.xlsx或者.xls结尾')
+        return
     abs_query_path = Path(query_path).absolute()
     if output_path:
         abs_output_path = Path(output_path).absolute() / output_name
@@ -48,7 +52,9 @@ def query4excel(query_content, query_path, output_path, output_name):
                 # if i == 0:
                 #     print(sheet.iloc[i].to_dict())
                 if query_content in current_row:
-                    current_row_df = pd.DataFrame(sheet.iloc[i].to_dict(), index=[0])
+                    file_dict = {"文件位置":str(excel)}
+                    file_dict.update(sheet.iloc[i].to_dict())
+                    current_row_df = pd.DataFrame(file_dict, index=[0])
                     res_df = res_df.append(current_row_df)
                     # print()
     # print(res_df)
